Compute the epsilon matrix by permutation for the sGBJ_scores() function.
.epsilon_matrix(Z, nperm, surv, factor_matrix, covariates = NULL, dat)The epsilon matrix.
the score vector returned by .survival_scores() function.
number of permutations performed to estimate the epsilon matrix.
Default is 300.
a Surv object of length n
a n x p data.frame of the expression for the
particular gene set of interest being tested
a n x l matrix of the covariates to adjust upon. Default is NULL
data used to fit survival model returned by .survival_scores() function.