Compute the survival score
.survival_scores(factor_matrix, covariates = NULL, surv)A list of length 3 with the updated factor_matrix (same as factor_matrix but removing columns for which survival model failed to converge), the Z matrix and the data used to fit survival model.
a n x p data.frame of the expression for
the particular gene set of interest being tested
a matrix nxl of the covariates to adjust. Default is NULL
a Surv object of length n